@@ -466,11 +466,6 @@ testthat::test_that("the 'cleanup' method (ESTIMATOR specific) works as expected
   skip_test_if_no_python()
   skip_test_if_no_module("rgf.sklearn")
 
-  #--------------------------------------------------------------------------------
-  # default directory where the temporary 'rgf' files are saved
-
-  default_dir = file.path(dirname(tempdir()), 'rgf')
-
   #--------------------------------------------------------------------------------
   # RGF
 
@@ -515,11 +510,6 @@ testthat::test_that("the 'cleanup' method (APPLIES TO ALL ESTIMATORS) works as e
   skip_test_if_no_python()
   skip_test_if_no_module("rgf.sklearn")
 
-  #--------------------------------------------------------------------------------
-  # default directory where the temporary 'rgf' files are saved
-
-  default_dir = file.path(dirname(tempdir()), 'rgf')
-
   #--------------------------------------------------------------------------------
   # RGF
 
@@ -549,4 +539,3 @@ testthat::test_that("the 'cleanup' method (APPLIES TO ALL ESTIMATORS) works as e
   testthat::expect_true( init_exists_upd_rgf && (init_num_files_rgf > 0) && (init_num_files_fastrgf > init_num_files_rgf) &&
                             ( init_num_files_rgf > length(lst_files_tmp) && init_num_files_fastrgf > length(lst_files_tmp_end_state) ) )       # normally, both initial and end state must have the same length [ length(lst_files_tmp) == length(lst_files_tmp_end_state) ]
 })
-
